@@ -22,6 +22,6 @@ def get_redis_pool(**redis_params_map) -> ConnectionPool:
     )
 
 
-def get_redis_connection() -> Redis:
+def get_redis_connection(**redis_params_map) -> Redis:
     # 使用连接池创建 Redis 客户端
-    return Redis(connection_pool=get_redis_pool())
+    return Redis(connection_pool=get_redis_pool(**redis_params_map))
